==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/SimulatePolicyEvaluationsEvaluated.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.SimulateResultPoliciesItems;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * A list of evaluated but not matched policies and rules
 */
@ApiModel(description = "A list of evaluated but not matched policies and rules")
@JsonPropertyOrder({ SimulatePolicyEvaluationsEvaluated.JSON_PROPERTY_POLICIES })
@JsonTypeName("SimulatePolicyEvaluations_evaluated")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class SimulatePolicyEvaluationsEvaluated implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_POLICIES = "policies";
    private List<SimulateResultPoliciesItems> policies = null;

    public SimulatePolicyEvaluationsEvaluated() {
    }

    public SimulatePolicyEvaluationsEvaluated policies(List<SimulateResultPoliciesItems> policies) {

        this.policies = policies;
        return this;
    }

    public SimulatePolicyEvaluationsEvaluated addpoliciesItem(SimulateResultPoliciesItems policiesItem) {
        if (this.policies == null) {
            this.policies = new ArrayList<>();
        }
        this.policies.add(policiesItem);
        return this;
    }

    /**
     * Get policies
     *
     * @return policies
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_POLICIES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<SimulateResultPoliciesItems> getPolicies() {
        return policies;
    }

    @JsonProperty(JSON_PROPERTY_POLICIES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPolicies(List<SimulateResultPoliciesItems> policies) {
        this.policies = policies;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        SimulatePolicyEvaluationsEvaluated simulatePolicyEvaluationsEvaluated = (SimulatePolicyEvaluationsEvaluated) o;
        return Objects.equals(this.policies, simulatePolicyEvaluationsEvaluated.policies);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(policies);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class SimulatePolicyEvaluationsEvaluated {\n");
        sb.append("    policies: ").append(toIndentedString(policies)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-21.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/SimulatePolicyEvaluationsEvaluated.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.SimulateResultPoliciesItems;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * A list of evaluated but not matched policies and rules
 */
@ApiModel(description = "A list of evaluated but not matched policies and rules")
@JsonPropertyOrder({ SimulatePolicyEvaluationsEvaluated.JSON_PROPERTY_POLICIES })
@JsonTypeName("SimulatePolicyEvaluations_evaluated")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class SimulatePolicyEvaluationsEvaluated implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_POLICIES = "policies";
    private List<SimulateResultPoliciesItems> policies = null;

    public SimulatePolicyEvaluationsEvaluated() {
    }

    public SimulatePolicyEvaluationsEvaluated policies(List<SimulateResultPoliciesItems> policies) {

        this.policies = policies;
        return this;
    }

    public SimulatePolicyEvaluationsEvaluated addpoliciesItem(SimulateResultPoliciesItems policiesItem) {
        if (this.policies == null) {
            this.policies = new ArrayList<>();
        }
        this.policies.add(policiesItem);
        return this;
    }

    /**
     * Get policies
     *
     * @return policies
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_POLICIES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<SimulateResultPoliciesItems> getPolicies() {
        return policies;
    }

    @JsonProperty(JSON_PROPERTY_POLICIES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPolicies(List<SimulateResultPoliciesItems> policies) {
        this.policies = policies;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        SimulatePolicyEvaluationsEvaluated simulatePolicyEvaluationsEvaluated = (SimulatePolicyEvaluationsEvaluated) o;
        return Objects.equals(this.policies, simulatePolicyEvaluationsEvaluated.policies);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(policies);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class SimulatePolicyEvaluationsEvaluated {\n");
        sb.append("    policies: ").append(toIndentedString(policies)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
